@@ -9,10 +9,8 @@ require Exporter;
 @EXPORT = qw(wrap fill);
 @EXPORT_OK = qw($columns $break $huge);
 
-$VERSION = '2021.0712';
-$SUBVERSION = 'modern';
-
-use 5.010_000;
+$VERSION = '2021.0722';
+$SUBVERSION = 'modern'; # back-compat vestige
 
 use vars qw($VERSION $SUBVERSION $columns $debug $break $huge $unexpand $tabstop $separator $separator2);
 use strict;
@@ -20,7 +18,7 @@ use strict;
 BEGIN	{
 	$columns = 76;  # <= screen width
 	$debug = 0;
-	$break = '(?=\s)\X';
+	$break = '(?=\s)(?:\r\n|\PM\pM*)';
 	$huge = 'wrap'; # alternatively: 'die' or 'overflow'
 	$unexpand = 1;
 	$tabstop = 8;
@@ -28,11 +26,7 @@ BEGIN	{
 	$separator2 = undef;
 }
 
-my $CHUNK = qr/\X/;
-
-sub _xlen(_) { scalar(() = $_[0] =~ /$CHUNK/g) }
-
-sub _xpos(_) { _xlen( substr( $_[0], 0, pos($_[0]) ) ) }
+sub _xlen { () = $_[0] =~ /\PM/g }
 
 use Text::Tabs qw(expand unexpand);
 
@@ -61,17 +55,17 @@ sub wrap
 
 	pos($t) = 0;
 	while ($t !~ /\G(?:$break)*\Z/gc) {
-		if ($t =~ /\G((?:(?=[^\n])\X){0,$ll})($break|\n+|\z)/xmgc) {
+		if ($t =~ /\G((?:(?!\n)\PM\pM*){0,$ll})($break|\n+|\z)/xmgc) {
 			$r .= $unexpand 
 				? unexpand($nl . $lead . $1)
 				: $nl . $lead . $1;
 			$remainder = $2;
-		} elsif ($huge eq 'wrap' && $t =~ /\G((?:(?=[^\n])\X){$ll})/gc) {
+		} elsif ($huge eq 'wrap' && $t =~ /\G((?:(?!\n)\PM\pM*){$ll})/gc) {
 			$r .= $unexpand 
 				? unexpand($nl . $lead . $1)
 				: $nl . $lead . $1;
 			$remainder = defined($separator2) ? $separator2 : $separator;
-		} elsif ($huge eq 'overflow' && $t =~ /\G((?:(?=[^\n])\X)*?)($break|\n+|\z)/xmgc) {
+		} elsif ($huge eq 'overflow' && $t =~ /\G((?:(?!\n)\PM\pM*)*?)($break|\n+|\z)/xmgc) {
 			$r .= $unexpand 
 				? unexpand($nl . $lead . $1)
 				: $nl . $lead . $1;
@@ -130,6 +124,7 @@ sub fill
 }
 
 1;
+
 __END__
 
 =head1 NAME
@@ -271,17 +266,6 @@ Result:
 
   "This is a bit of|text that forms a|normal book-style|paragraph"
 
-=head1 SUBVERSION
-
-This module comes in two flavors: one for modern perls (5.10 and above)
-and one for ancient obsolete perls.  The version for modern perls has
-support for Unicode.  The version for old perls does not.  You can tell
-which version you have installed by looking at C<$Text::Wrap::SUBVERSION>:
-it is C<old> for obsolete perls and C<modern> for current perls.
-
-This man page is for the version for modern perls and so that's probably
-what you've got.
-
 =head1 SEE ALSO
 
 For correct handling of East Asian half- and full-width characters, 
